# Common Inkove tasks for working with Python/Docker/K8s

[Inkove][invoke] (or pyinvoke) is a tool for automating tasks made in Python.

This package define a set of common tasks you can use if working with 
Python (and it's popular frameworks), Docker and Kubernetes.

[invoke]: https://pyinvoke.org
